==> open-xchange-mobile-api-facade_1.0.3.orig.tar.bz2: open-xchange-mobile-api-facade-1.0.3/com.openexchange.mobile.api.facade/src/com/openexchange/mobile/api/facade/services/VersionService.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.mobile.api.facade.services;

import com.openexchange.mobile.api.facade.BuildInfo;
import com.openexchange.mobile.api.facade.connectors.ConnectorFactory;
import com.openexchange.mobile.api.facade.connectors.ConnectorFactoryFactory;
import com.openexchange.mobile.api.facade.connectors.impl.VersionConnector;
import com.openexchange.mobile.api.facade.connectors.responses.VersionResponseMto;
import com.openexchange.mobile.api.facade.models.Version;

import lombok.RequiredArgsConstructor;
import lombok.val;

import org.osgi.framework.FrameworkUtil;

@RequiredArgsConstructor
public class VersionService {

    private final ConnectorFactoryFactory connectorFactoryFactory;

    public Version getVersion() {
        val versionString = getBundleVersion();
        val commitHash = getCommitHash();
        val middlewareVersion = getMiddlewareVersion();
        return new Version(versionString, commitHash, middlewareVersion);
    }

    /*private*/ String getBundleVersion() {
        return FrameworkUtil.getBundle(getClass()).getVersion().toString();
    }

    /*private*/ String getCommitHash() {
        return BuildInfo.gitCommit;
    }

    private String getMiddlewareVersion() {
        ConnectorFactory connectorFactory = connectorFactoryFactory.getConnectorFactory();
        VersionConnector connector = connectorFactory.getVersionConnector();
        VersionResponseMto response = connector.execute();
        return response.getData().getVersion();
    }

}

==> open-xchange-mobile-api-facade_1.6.10.orig.tar.bz2: open-xchange-mobile-api-facade-1.6.10/com.openexchange.mobile.api.facade/src/com/openexchange/mobile/api/facade/services/VersionService.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.mobile.api.facade.services;

import com.openexchange.mobile.api.facade.BuildInfo;
import com.openexchange.mobile.api.facade.connectors.ConnectorFactory;
import com.openexchange.mobile.api.facade.connectors.ConnectorFactoryFactory;
import com.openexchange.mobile.api.facade.connectors.impl.VersionConnector;
import com.openexchange.mobile.api.facade.connectors.responses.VersionResponseMto;
import com.openexchange.mobile.api.facade.models.Version;

import lombok.RequiredArgsConstructor;
import lombok.val;

import org.osgi.framework.FrameworkUtil;

@RequiredArgsConstructor
public class VersionService {

    private final ConnectorFactoryFactory connectorFactoryFactory;

    public Version getVersion() {
        val versionString = getBundleVersion();
        val commitHash = getCommitHash();
        val middlewareVersion = getMiddlewareVersion();
        return new Version(versionString, commitHash, middlewareVersion);
    }

    public String getBundleVersion() {
        return FrameworkUtil.getBundle(getClass()).getVersion().toString();
    }

    /*private*/ String getCommitHash() {
        return BuildInfo.gitCommit;
    }

    private String getMiddlewareVersion() {
        ConnectorFactory connectorFactory = connectorFactoryFactory.getConnectorFactory();
        VersionConnector connector = connectorFactory.getVersionConnector();
        VersionResponseMto response = connector.execute();
        return response.getData().getVersion();
    }

}
